@@ -14,19 +14,27 @@ Transmission::Client - Interface to Transmission
 
 =head1 VERSION
 
-0.0803
+0.0806
 
 =head1 DESCRIPTION
 
-L<Transmission::Client> is the main module in a collection of modules to
-communicate with Transmission. Transmission is:
+L<Transmission::Client> is the main module in a collection of modules
+to communicate with Transmission. Transmission is a cross-platform
+BitTorrent client that is:
 
- Transmission is a cross-platform BitTorrent client that is:
-  * Easy
-  * Lean
-  * Native
-  * Powerful
-  * Free
+=over
+
+=item * Easy
+
+=item * Lean
+
+=item * Native
+
+=item * Powerful
+
+=item * Free
+
+=back
 
 If you want to communicate with "transmission-daemon", this is a module
 which can help you with that.
@@ -84,16 +92,16 @@ L<Transmission::Utils>
 use Moose;
 use DateTime;
 use DateTime::Duration;
-use JSON::Any;
+use JSON::MaybeXS;
 use LWP::UserAgent;
 use MIME::Base64;
 use Transmission::Torrent;
 use Transmission::Session;
 use constant RPC_DEBUG => $ENV{'TC_RPC_DEBUG'};
 
-our $VERSION = '0.0803';
+our $VERSION = '0.0806';
 our $SESSION_ID_HEADER_NAME = 'X-Transmission-Session-Id';
-my $JSON = JSON::Any->new;
+my $JSON = JSON::MaybeXS->new;
 
 with 'Transmission::AttributeRole';
 
@@ -299,13 +307,13 @@ has session_id => (
 
  $bool = $self->add(%args);
 
- key              | value type & description
- -----------------+-------------------------------------------------
- download_dir     | string    path to download the torrent to
- filename         | string    filename or URL of the .torrent file
- metainfo         | string    torrent content
- paused           | boolean   if true, don't start the torrent
- peer_limit       | number    maximum number of peers
+ key              | value type | description
+ -----------------+------------+------------------------------------
+ download_dir     | string     | path to download the torrent to
+ filename         | string     | filename or URL of the .torrent file
+ metainfo         | string     | torrent content
+ paused           | boolean    | if true, don't start the torrent
+ peer_limit       | number     | maximum number of peers
 
 Either "filename" or "metainfo" MUST be included. All other arguments are
 optional.
@@ -340,10 +348,10 @@ sub add {
 
  $bool = $self->remove(%args);
 
- key                | value type & description
- -------------------+-------------------------------------------------
- ids                | array    torrent list, as described in 3.1
- delete_local_data  | boolean  delete local data. (default: false)
+ key                | value type | description
+ -------------------+------------+------------------------------------
+ ids                | array      | torrent list, as described in 3.1
+ delete_local_data  | boolean    | delete local data. (default: false)
 
 C<ids> can also be the string "all". C<ids> is required.
 
@@ -369,12 +377,12 @@ sub remove {
  $bool = $self->move(%args);
 
 
- string      | value type & description
- ------------+-------------------------------------------------
- ids         | array      torrent list, as described in 3.1
- location    | string     the new torrent location
- move        | boolean    if true, move from previous location.
-             |            otherwise, search "location" for files
+ string      | value type | description
+ ------------+------------+------------------------------------
+ ids         | array      | torrent list, as described in 3.1
+ location    | string     | the new torrent location
+ move        | boolean    | if true, move from previous location.
+             |            | otherwise, search "location" for files
 
 C<ids> can also be the string "all". C<ids> and C<location> is required.
 
@@ -458,11 +466,10 @@ sub _do_ids_action {
  @list = $self->read_torrents(%args);
  $array_ref = $self->read_torrents(%args);
 
- key         | value type & description
- ------------+-------------------------------------------------
- ids         | array      torrent list, as described in 3.1
-             |            this is optional
- lazy_read   | will create objects with as little data as possible.
+ key         | value type | description
+ ------------+------------+------------------------------------
+ ids         | array      | optional torrent list, as described in 3.1.
+ lazy_read   |            | will create objects with as little data as possible.
 
 =over 4
 
@@ -635,15 +642,22 @@ the same terms as Perl itself.
 
 =head1 COPYRIGHT AND AUTHORS
 
-Copyright 2009-2013, Jan Henning Thorsen <jhthorsen@cpan.org> and contributors
+Copyright 2009-2019 by Transmission::Client contributors
 
-Current maintainer: Olof Johansson - C<olof@cpan.org>
+See C<git log --format="%aN E<lt>%aEE<gt>" | sort | uniq> in the git repository
+for the reference list of contributors.
 
 =head2 CONTRIBUTORS
 
 =over
 
-=item Andrew Fresh
+=item * Jan Henning Thorsen (original author)
+
+=item * Olof Johansson (current maintainer)
+
+=item * Andrew Fresh
+
+=item * Yanick Champoux
 
 =back
 
